pub struct DerivedTableAdapter<'a> { /* private fields */ }Expand description
Adapter that stores one versioned graph record in an ordinary SIM Table.
The adapter deliberately uses only Table operations and ordinary Expr
data. Durability, transactions, and host effects remain properties of the
selected backend.
Implementations
Sourceimpl<'a> DerivedTableAdapter<'a>
impl<'a> DerivedTableAdapter<'a>
Sourcepub fn new(table: &'a dyn Table, cx: &'a mut Cx) -> Self
pub fn new(table: &'a dyn Table, cx: &'a mut Cx) -> Self
Targets DERIVED_SNAPSHOT_KEY in table.
Sourcepub fn with_key(table: &'a dyn Table, cx: &'a mut Cx, key: Symbol) -> Self
pub fn with_key(table: &'a dyn Table, cx: &'a mut Cx, key: Symbol) -> Self
Targets an explicit Table key.
Sourcepub fn delete(&mut self) -> Result<(), DerivedSnapshotError>
pub fn delete(&mut self) -> Result<(), DerivedSnapshotError>
Deletes the rebuildable graph record, if present.